Package: egg
Type: Package
Title: Extensions for 'ggplot2': Custom Geom, Custom Themes, Plot
        Alignment, Labelled Panels, Symmetric Scales, and Fixed Panel
        Size
Version: 0.4.5
Authors@R: c(person("Baptiste", "Auguie",
    email = "baptiste.auguie@gmail.com",
    role = c("aut", "cre")))
License: GPL-3
Description: Miscellaneous functions to help customise 'ggplot2' objects. High-level functions are provided to post-process 'ggplot2' layouts and allow alignment between plot panels, as well as setting panel sizes to fixed values. Other functions include a custom 'geom', and helper functions to enforce symmetric scales or add tags to facetted plots.
VignetteBuilder: knitr
Depends: gridExtra (>= 2.3), ggplot2
Imports: gtable, grid, grDevices, utils
Suggests: knitr, png
RoxygenNote: 6.1.1
NeedsCompilation: no
Packaged: 2019-07-13 05:29:16 UTC; baptiste
Author: Baptiste Auguie [aut, cre]
Maintainer: Baptiste Auguie <baptiste.auguie@gmail.com>
Repository: CRAN
Date/Publication: 2019-07-13 06:00:27 UTC
