Egg version 4.2.0

					                NIIBE Yutaka
					                  2015-04-30

This is another Egg V4 release by the original author.  This release
requires newer Anthy (than version 0.3).

The official maintainer at AIST has no interest about maintenance of
this software.  Official Mailing list, homepage, and FTP site are all
gone now.

Until the official maintainer will work again for the real release (as
he once primised to me), for the time being, I keep this package
running on newer Emacs and newer Anthy.

This release only supports Anthy backend and it's Japanese-only.

Old files are moved to the ATTIC directory.  It will be removed in the
next release, perhaps.  In those files, SJ3 support would work, but I
don't have SJ3 at hand, so, it's not guaranteed.

If you need other features than that, please ask the official
maintainer or use old software with old Emacs.
-- 
