
			   Tamago Version 4

		   NIIBE Yutaka <gniibe@chroot.org>
		   KATAYAMA Yoshio <kate@pfu.co.jp>
		   TOMURA Satoru <tomura@etl.go.jp>


「たまご第4版」(Tamago 4)を公開します。使用許諾条件は GPL です。すべて
のソースが Emacs Lisp で実現されており、GNU Emacs 20.5 以降で多言語入
力環境を提供します。バックエンドサーバとしては、FreeWnn (jserver,
cserver, tserver), Wnn6, SJ3 Ver.2 に対応しています。

FTP site は http://www.m17n.org/pub/tamago です。公式ホームページは
http://www.m17n.org/tamago です。

インストールの方法としては、ファイルを解凍して (1) ./configure, (2)
make, (3) make install を実行してください。

M-x set-language-enviromant などで Language-environment を Japanese に
設定すると default input method が japanese-egg-wnn になっています。

Tamago project に関する議論等は Tamago mailing list で行っています。
Tamago project に参加したい方、Tamago 実装を使ってみたい方、Tamago 実
装についての質問・要望、その他 Tamago に関する議論に参加したい方をお待
ちしています。

Tamago mailing list に参加希望の方は tamago-ctl@m17n.org 宛にメイルの
本文に　

   subscribe あなたの名前 

の一行を書いた mail をお送りください。 その後、確認の mail を届きます
ので、その mail の中にある

   confirm PASSWORD あなたの名前 

の１行を本文にして返事を送ってください。 


参考資料として片山さんが Linux Conference 99 で発表した Egg V4 (Egg
Next Generation) をテキストファイルにしたものを doc/lc99.text の置きま
した。ご覧下さい。


From Tamago 4 管理人

戸村 哲（とむら さとる） 〒305-8568 茨城県つくば市梅園1-1-4 
電子技術総合研究所 情報アーキテクチャ部
E-mail: tomura@etl.go.jp Phone: 0298-54-5887 FAX: 0298-54-5891 


